/**CHeaderFile*****************************************************************

  FileName    [ cceInt.h ]

  PackageName [ cce ]

  Synopsis    [ C++ documentation extractor ]

  Description [

A simple object-oriented database with a Tcl interface driven by a
flex/bison parser. <P>

<H2>The Object System</H2>

The objects are arrays of void *s, whose values are cast as necessary. <P>

The first few slots are the same for all objects:

<DL COMPACT>
<DT> 0 <DD> <TT>class</TT>	The class of the object (object)
<DT> 1 <DD> <TT>id</TT>		The id of the object (int)
<DT> 2 <DD> <TT>next</TT>	The next object in the list, if any (object)
</DL>

The remaining slots vary from class to class. <P>

Objects in the <EM>Class</EM> class have following layout:

<DL COMPACT>
<DT> 3 <DD> <TT>name</TT>	Name of class (string)
<DT> 4 <DD> <TT>numObject</TT>  Number of objects built for this class (int)
<DT> 5 <DD> <TT>numSlots</TT>   Number of slots in this class (int)
<DT> 6 <DD> <TT>slots</TT>	Slots of this class (object)
</DL>

Objects in the <EM>Slot</EM> class have the following layout:

<DL COMPACT>
<DT> 3 <DD> <TT>name</TT>	Name of the slot (string)
<DT> 4 <DD> <TT>type</TT>	Type of the slot (integer)
</DL>

The following slot types are supported:

<DL COMPACT>
<DT> 0 <DD> object <TT>CCE_OBJECT</TT>
<DT> 1 <DD> string <TT>CCE_STRING</TT>
<DT> 2 <DD> integer <TT>CCE_INTEGER</TT>
</DL>

<HR>

For more information, see <A HREF="cceObjectDoc.html">the documentation for
built-in objects</A>

]

  Author      [ Stephen A. Edwards <sedwards@eecs.berkeley.edu> ]

  Copyright   []

  Revision    []

******************************************************************************/

#ifndef _CCEINT
#define _CCEINT

#define EXTERN extern

#include "cce.h"

/**Variable********************************************************************
  Synopsis    [ An array of strings naming field types ]
******************************************************************************/
extern char * cceSlotTypeNames[];

/**Macro***********************************************************************
  Synopsis     [ Duplicate a string by malloc'ing ]
  SideEffects  []
******************************************************************************/
#define /* char * */ Cce_StringDup( /* char */ s) \
  (strcpy( (char *) malloc( strlen(s) + 1), (s) ))

/**AutomaticStart*************************************************************/

/*---------------------------------------------------------------------------*/
/* Function prototypes                                                       */
/*---------------------------------------------------------------------------*/

EXTERN int main(int argc, char ** argv);
EXTERN void CceRegisterObject(Cce_Object object);

/**AutomaticEnd***************************************************************/

#endif /* _CCEINT */
